Welcome to ladybug-charts's documentation!
===================================

.. image:: https://raw.githubusercontent.com/ladybug-tools/ladybug-charts/master/images/charts.png

Ladybug extension for generating 2D charts.

Installation
============

``pip install -U ladybug-charts``

.. toctree::
   :maxdepth: 4
   :caption: Contents:

.. include:: modules.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
